// java wrapper for vtkZLibDataCompressor object
//

package vtk;
import vtk.*;

public class vtkZLibDataCompressor extends vtkDataCompressor
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetCompressionLevel_2();
  public int GetCompressionLevel()
    { return GetCompressionLevel_2(); }

  private native void SetCompressionLevel_3(int id0);
  public void SetCompressionLevel(int id0)
    { SetCompressionLevel_3(id0); }

  public vtkZLibDataCompressor() { super(); }

  public vtkZLibDataCompressor(long id) { super(id); }
  public native long   VTKInit();

}
